package com.ruoyi.web.modules.architecture.service;

import java.util.List;
import com.ruoyi.web.modules.architecture.domain.BizWithdrawalPeriodStandard;

/**
 * 休药期标准 服务
 */
public interface IBizWithdrawalPeriodStandardService
{
    BizWithdrawalPeriodStandard selectBizWithdrawalPeriodStandardById(Long id);

    List<BizWithdrawalPeriodStandard> selectBizWithdrawalPeriodStandardList(BizWithdrawalPeriodStandard query);

    int insertBizWithdrawalPeriodStandard(BizWithdrawalPeriodStandard row);

    int updateBizWithdrawalPeriodStandard(BizWithdrawalPeriodStandard row);

    int deleteBizWithdrawalPeriodStandardByIds(Long[] ids);

    int syncKb(Long id);

    int removeKb(Long id);
}
